@@ -23,7 +23,7 @@
 #include <math.h>
 #include <getopt.h>
 
-#define VERSION "1.3"
+#define VERSION "1.4"
 #define max(A,B) ( (A) > (B) ? (A):(B))
 #define min(A,B) ( (A) > (B) ? (B):(A))
 #define who_play(i) ((i % 12) / 6)   //Return the player (0 ou 1) of hole i.
@@ -214,8 +214,9 @@ main (int argc, char *argv[])
   -l L, --level=L level L=1, 2 or 3 of game (default L=1)\n\
   -e E, --eat=E   maximum number of holes which can be eaten (default E=4)\n\
   -m, --noeatmore eat nothing when trying to eat more than E holes\n\
-  -a, --noeatall  eat nothing when trying to eat all remaining seeds\n\
-  -k, --noattackall forbiden to attack all the opponent seeds\n\
+  -a, --noeatall  eat nothing when trying to eat all opponent seeds\n\
+  -k, --noattackall forbiden to attack all opponent seeds excepted if this is the\n\
+                  only possible move\n\
   -s, --single    process a single move\n\
   -i, --hint      print hints\n\
   -x  --xawale    start in engine mode. A single line output is provided at\n\
@@ -260,7 +261,15 @@ eaten. It is possible to eat a maximum of four holes, when five holes are\n\
 eatable, only the last four ones are eaten.\n\n\
 Players have to play such that the opponent always has at least one seed.\n\
 In case it is impossible, the game stops.\n\n\
-The winner is the player who has eaten the most seeds.\n");
+The winner is the player who has eaten the most seeds.\n\n\
+VARIANTS:\n\
+It exists many variants in Africa. Most of them can be played by configuring\n\
+the rule with the four following parameters.\n\
+- the maximum number E of holes that can be eaten can be modified (E=1 to 6).\n\
+- instead of eating the last E holes when attacking more, you eat nothing.\n\
+- you can forbid any move attacking all opponent seeds excepted if this is the\n\
+  only possible move.\n\
+- in case all opponent seeds are attacked, nothing is eaten.\n");
 
       exit (0);
     }
