@@ -16,7 +16,7 @@
 #  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
 #  USA
 #
-# Version 1.3 last modified on May 6th, 2008.
+# Version 1.4 last modified on July 29th, 2009.
 #
 #!/bin/bash
 # start wish \
@@ -116,11 +116,23 @@ close $fid
 #ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
 
 proc openConf {} {
-global PATH LANG
+global PATH LANG level nbeat noeat noall noatk start
 
 if {![catch {open [file join ~ .xawale.ini] r} fid]} {
 gets $fid line
 scan $line "LANG=%2s" LANG
+gets $fid line
+scan $line "LEVEL=%1s" level
+gets $fid line
+scan $line "NBEAT=%1s" nbeat
+gets $fid line
+scan $line "NOEAT=%1s" noeat
+gets $fid line
+scan $line "NOALL=%1s" noall
+gets $fid line
+scan $line "NOATK=%1s" noatk
+gets $fid line
+scan $line "START=%s" start
 close $fid
 }
 
@@ -131,10 +143,16 @@ close $fid
 #ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
 
 proc saveConf {} {
-global PATH LANG
+global PATH LANG level nbeat noeat noall noatk start
 
 if {![catch {open [file join ~ .xawale.ini] w} fid]} {
 puts $fid LANG=$LANG
+puts $fid LEVEL=$level
+puts $fid NBEAT=$nbeat
+puts $fid NOEAT=$noeat
+puts $fid NOALL=$noall
+puts $fid NOATK=$noatk
+puts $fid START=$start
 close $fid
 }
 
@@ -142,18 +160,16 @@ close $fid
 
 #ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
 #                     Undo : cancel a turn
-# Last modified 5 may 2008
-# the line
-#  if {$label=="RUN"&$iturn>=2} {
-# has been replaced by
-#  if {$iturn>=2} {
+# Last modified 6 june 2008
 #ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
 
 proc undo {} {
-global trou gain label
+global trou gain label level
 global turn iturn
-if {$iturn>=2} {
-incr iturn -2
+set undo no
+if {$level=="H"&$iturn>=1} {incr iturn -1; set undo yes}
+if {$level!="H"&$iturn>=2} {incr iturn -2; set undo yes}
+if {$undo=="yes"} {
 scan $turn($iturn) "board=%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u score=%u-%u move=%u %6s" \
                 trou(0) trou(1) trou(2) trou(3) trou(4) trou(5) \
                 trou(6) trou(7) trou(8) trou(9) trou(10) trou(11) \
@@ -168,10 +184,10 @@ affichage NULL
 #ccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
 
 proc affichage {mvt} {
-global LANG WIN LOSE DRAW CSCO PSCO P1CO P2CO DEPT TURN
+global LANG WIN LOSE DRAW NWIN SWIN CSCO PSCO P1CO P2CO DEPT TURN
 global level
 global trou gain label depth
-global img idtrou indication
+global img idtrou mvtcircle indication
 global turn iturn
 
 set a 74
@@ -180,6 +196,7 @@ set b 83
 set c 4
 
 for {set i 0} {$i<12} {incr i} {.cnv delete $idtrou($i)}
+.cnv delete $mvtcircle
 
 set idtrou(11)  [.cnv create image [expr 52+$b*0] [expr 135] -image $img($trou(11))]
 set idtrou(10)  [.cnv create image [expr 52+$b*1] [expr 133] -image $img($trou(10))]
@@ -195,20 +212,20 @@ set idtrou(4)   [.cnv create image [expr 58+$b*4] [expr 214] -image $img($trou(4
 set idtrou(5)   [.cnv create image [expr 58+$b*5] [expr 212] -image $img($trou(5))]
 
 set idtrou(12)  [.cnv create image [expr 60+$b*2] [expr 43] -image $img($gain(1))]
-if {$gain(1)>9} {
-set idtrou(13)  [.cnv create image [expr 63+$b*3] [expr 45] -image $img([expr $gain(1)-9])]
+if {$gain(1)>15} {
+set idtrou(13)  [.cnv create image [expr 63+$b*3] [expr 45] -image $img([expr $gain(1)-15])]
 } else {
 set idtrou(13)  [.cnv create image [expr 63+$b*3] [expr 45] -image $img(0)]
 }
 set idtrou(14)  [.cnv create image [expr 68+$b*2] [expr 308] -image $img($gain(0))]
-if {$gain(0)>9} {
-set idtrou(15)  [.cnv create image [expr 68+$b*3] [expr 305] -image $img([expr $gain(0)-9])]
+if {$gain(0)>15} {
+set idtrou(15)  [.cnv create image [expr 68+$b*3] [expr 305] -image $img([expr $gain(0)-15])]
 } else {
 set idtrou(15)  [.cnv create image [expr 68+$b*3] [expr 305] -image $img(0)]
 }
 
 .cnv delete $indication
-if {$level=="2players"} {
+if {$level=="H"} {
    set indication [.cnv create text 70 30 \
    -text "$P1CO($LANG) $gain(1)\n$P2CO($LANG) $gain(0)\n$DEPT($LANG) $depth $TURN($LANG) $iturn"]
 } else {
@@ -217,28 +234,19 @@ if {$level=="2players"} {
 }
 
 # surlignagne du trou venant d'etre joue
-if {$mvt=="12"} {
-set mvtcircle [.cnv create oval [expr 15+$b*0] [expr 98] [expr 15+$b*0+$a] [expr 98+$a] -width $c] 
-after 1000 ".cnv delete $mvtcircle"
-}
-if {$mvt=="11"} {
-set mvtcircle [.cnv create oval [expr 15+$b*1] [expr 96] [expr 15+$b*1+$a] [expr 96+$a] -width $c] 
-after 1000 ".cnv delete $mvtcircle"
-}
-if {$mvt=="10"} {
-set mvtcircle [.cnv create oval [expr 16+$b*2] [expr 94] [expr 16+$b*2+$a] [expr 94+$a] -width $c] 
-after 1000 ".cnv delete $mvtcircle"
-}
-if {$mvt=="9"} {
-set mvtcircle [.cnv create oval [expr 18+$b*3] [expr 92] [expr 18+$b*3+$a] [expr 92+$a] -width $c] 
-after 1000 ".cnv delete $mvtcircle"
-}
-if {$mvt=="8"} {
-set mvtcircle [.cnv create oval [expr 20+$b*4] [expr 93] [expr 20+$b*4+$a] [expr 93+$a] -width $c] 
-after 1000 ".cnv delete $mvtcircle"
-}
-if {$mvt=="7"} {
-set mvtcircle [.cnv create oval [expr 21+$b*5] [expr 94] [expr 21+$b*5+$a] [expr 94+$a] -width $c] 
+if {$label!="ERR"&$mvt>=1&$mvt<=12} {
+if {$mvt=="12"} {set mvtcircle [.cnv create oval [expr 15+$b*0] [expr  98] [expr 15+$b*0+$a] [expr  98+$a] -width $c]}
+if {$mvt=="11"} {set mvtcircle [.cnv create oval [expr 15+$b*1] [expr  96] [expr 15+$b*1+$a] [expr  96+$a] -width $c]}
+if {$mvt=="10"} {set mvtcircle [.cnv create oval [expr 16+$b*2] [expr  94] [expr 16+$b*2+$a] [expr  94+$a] -width $c]}
+if {$mvt=="9"}  {set mvtcircle [.cnv create oval [expr 18+$b*3] [expr  92] [expr 18+$b*3+$a] [expr  92+$a] -width $c]}
+if {$mvt=="8"}  {set mvtcircle [.cnv create oval [expr 20+$b*4] [expr  93] [expr 20+$b*4+$a] [expr  93+$a] -width $c]}
+if {$mvt=="7"}  {set mvtcircle [.cnv create oval [expr 21+$b*5] [expr  94] [expr 21+$b*5+$a] [expr  94+$a] -width $c]}
+if {$mvt=="6"}  {set mvtcircle [.cnv create oval [expr 22+$b*5] [expr 175] [expr 22+$b*5+$a] [expr 175+$a] -width $c]}
+if {$mvt=="5"}  {set mvtcircle [.cnv create oval [expr 22+$b*4] [expr 176] [expr 22+$b*4+$a] [expr 176+$a] -width $c]}
+if {$mvt=="4"}  {set mvtcircle [.cnv create oval [expr 22+$b*3] [expr 175] [expr 22+$b*3+$a] [expr 175+$a] -width $c]}
+if {$mvt=="3"}  {set mvtcircle [.cnv create oval [expr 22+$b*2] [expr 176] [expr 22+$b*2+$a] [expr 176+$a] -width $c]}
+if {$mvt=="2"}  {set mvtcircle [.cnv create oval [expr 17+$b*1] [expr 180] [expr 17+$b*1+$a] [expr 180+$a] -width $c]}
+if {$mvt=="1"}  {set mvtcircle [.cnv create oval [expr 17+$b*0] [expr 180] [expr 17+$b*0+$a] [expr 180+$a] -width $c]}
 after 1000 ".cnv delete $mvtcircle"
 }
 
@@ -246,10 +254,17 @@ update
 
 # fin de partie
 if {$label=="END"} {
+  if {$level!="H"} {
+     set S $LOSE($LANG)
+     set N $WIN($LANG)
+  } else {
+     set S $SWIN($LANG)
+     set N $NWIN($LANG)
+  }
   if {$gain(0)>$gain(1)} {
-  tk_messageBox -message $LOSE($LANG)
+  tk_messageBox -message $S
   } elseif {$gain(0)<$gain(1)} {
-  tk_messageBox -message $WIN($LANG)
+  tk_messageBox -message $N
   } else {
   tk_messageBox -message $DRAW($LANG)
   }
@@ -278,11 +293,11 @@ if {$ligne!=1&$ligne!=2} {return}
 update
 
 # player move
-if {$level!="2players"&&$ligne==2&&$label=="RUN"||$level=="2players"&&$label=="RUN"} {
+if {$level!="H"&&$ligne==2&&$label=="RUN"||$level=="H"&&$label=="RUN"} {
 
   set turn([incr iturn]) [exec $JOUER \
     -b $trou(0)-$trou(1)-$trou(2)-$trou(3)-$trou(4)-$trou(5)-$trou(6)-$trou(7)-$trou(8)-$trou(9)-$trou(10)-$trou(11) \
-    -o $gain(0)-$gain(1) -p $trou0 -e $nbeat -sx$noeat$noall$noatk]
+    -o $gain(0)-$gain(1) -p $trou0 -e $nbeat [string map {" " ""} -sx$noeat$noall$noatk]]
   scan $turn($iturn) "board=%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u score=%u-%u move=%u %6s" \
                 trou(0) trou(1) trou(2) trou(3) trou(4) trou(5) \
                 trou(6) trou(7) trou(8) trou(9) trou(10) trou(11) \
@@ -294,12 +309,12 @@ if {$level!="2players"&&$ligne==2&&$label=="RUN"||$level=="2players"&&$label=="R
 }
 
 # computer move
-if {$level!="2players"&&$ligne==2&&$label=="RUN"||$level!="2players"&&$label=="RUN"&&$start=="COMPUTER"} {
+if {$level!="H"&&$ligne==2&&$label=="RUN"||$level!="H"&&$label=="RUN"&&$start=="COMPUTER"} {
 
   set time0 [clock seconds]
   set turn([incr iturn]) [exec $JOUER \
     -b $trou(0)-$trou(1)-$trou(2)-$trou(3)-$trou(4)-$trou(5)-$trou(6)-$trou(7)-$trou(8)-$trou(9)-$trou(10)-$trou(11) \
-    -o $gain(0)-$gain(1) -c 2 -d $depth -e $nbeat -sx$noeat$noall$noatk]
+    -o $gain(0)-$gain(1) -c 2 -d $depth -e $nbeat [string map {" " ""} -sx$noeat$noall$noatk]]
   scan $turn($iturn) "board=%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u score=%u-%u move=%u %6s" \
                 trou(0) trou(1) trou(2) trou(3) trou(4) trou(5) \
                 trou(6) trou(7) trou(8) trou(9) trou(10) trou(11) \
@@ -342,25 +357,25 @@ return 0
 
 proc contenu {x y w h} {
 global level depth
-global trou gain label
+global trou gain label LANG SEED
 
 set ligne [format %.0f [expr floor(4*$y/$h)]]
 set colon [format %.0f [expr floor(6*$x/$w)]]
 
 if {$ligne==0&$label=="RUN"} {
-   after 1000 ".cnv delete [.cnv create text 38 70 -text "$gain(1) seed(s)"]"
+   after 1000 ".cnv delete [.cnv create text 38 70 -text "$gain(1) $SEED($LANG)"]"
 }
 
 if {$ligne==1&$label=="RUN"} {
-   after 1000 ".cnv delete [.cnv create text 38 70 -text "$trou([expr 11-$colon]) seed(s)"]"
+   after 1000 ".cnv delete [.cnv create text 38 70 -text "$trou([expr 11-$colon]) $SEED($LANG)"]"
 }
 
 if {$ligne==2&$label=="RUN"} {
-   after 1000 ".cnv delete [.cnv create text 38 70 -text "$trou($colon) seed(s)"]"
+   after 1000 ".cnv delete [.cnv create text 38 70 -text "$trou($colon) $SEED($LANG)"]"
 }
 
 if {$ligne==3&$label=="RUN"} {
-   after 2000 ".cnv delete [.cnv create text 38 70 -text "$gain(0) seed(s)"]"
+   after 2000 ".cnv delete [.cnv create text 38 70 -text "$gain(0) $SEED($LANG)"]"
 }
 
 
@@ -401,24 +416,11 @@ pack   .configure.frame1.eat.lbl.1 -side top -anchor w
 pack   .configure.frame1.eat.lbl.2 -side top -anchor w
 
 frame  .configure.frame1.eat.chk
-radiobutton .configure.frame1.eat.chk.1 -variable noeat -value ""
+radiobutton .configure.frame1.eat.chk.1 -variable noeat -value " "
 radiobutton .configure.frame1.eat.chk.2 -variable noeat -value "m"
 pack   .configure.frame1.eat.chk.1 -side top
 pack   .configure.frame1.eat.chk.2 -side top
 
-frame  .configure.frame1.all -borderwidth 10
-frame  .configure.frame1.all.lbl
-label  .configure.frame1.all.lbl.1 -text $EATA($LANG)
-label  .configure.frame1.all.lbl.2 -text $NOAL($LANG)
-pack   .configure.frame1.all.lbl.1 -side top -anchor w
-pack   .configure.frame1.all.lbl.2 -side top -anchor w
-
-frame  .configure.frame1.all.chk
-radiobutton .configure.frame1.all.chk.1 -variable noall -value ""
-radiobutton .configure.frame1.all.chk.2 -variable noall -value "a"
-pack   .configure.frame1.all.chk.1 -side top
-pack   .configure.frame1.all.chk.2 -side top
-
 frame  .configure.frame1.atk -borderwidth 10
 frame  .configure.frame1.atk.lbl
 label  .configure.frame1.atk.lbl.1 -text $ATKA($LANG)
@@ -427,19 +429,32 @@ pack   .configure.frame1.atk.lbl.1 -side top -anchor w
 pack   .configure.frame1.atk.lbl.2 -side top -anchor w
 
 frame  .configure.frame1.atk.chk
-radiobutton .configure.frame1.atk.chk.1 -variable noatk -value ""
+radiobutton .configure.frame1.atk.chk.1 -variable noatk -value " "
 radiobutton .configure.frame1.atk.chk.2 -variable noatk -value "k"
 pack   .configure.frame1.atk.chk.1 -side top
 pack   .configure.frame1.atk.chk.2 -side top
 
+frame  .configure.frame1.all -borderwidth 10
+frame  .configure.frame1.all.lbl
+label  .configure.frame1.all.lbl.1 -text $EATA($LANG)
+label  .configure.frame1.all.lbl.2 -text $NOAL($LANG)
+pack   .configure.frame1.all.lbl.1 -side top -anchor w
+pack   .configure.frame1.all.lbl.2 -side top -anchor w
+
+frame  .configure.frame1.all.chk
+radiobutton .configure.frame1.all.chk.1 -variable noall -value " "
+radiobutton .configure.frame1.all.chk.2 -variable noall -value "a"
+pack   .configure.frame1.all.chk.1 -side top
+pack   .configure.frame1.all.chk.2 -side top
+
 frame  .configure.button
 button .configure.button.ok      -text $OK($LANG)   -command {destroy .configure}
 button .configure.button.default -text $DEFA($LANG) -command {
                                                            global noeat nbeat noall noatk
-                                                           set noeat ""
+                                                           set noeat " "
                                                            set nbeat 4
-                                                           set noall ""
-                                                           set noatk ""
+                                                           set noall " "
+                                                           set noatk " "
                                                           }
 #button .configure.button.cancel -text "CANCEL" -command {destroy .configure}
 pack .configure.button.ok      -side left  -ipadx 18 -padx 5 -pady 5
@@ -450,14 +465,14 @@ pack .configure.button.default -side right -padx 5 -pady 5
 pack .configure.frame1         -side top
 pack .configure.frame1.nbeat   -side top   -anchor w
 pack .configure.frame1.eat     -side top   -anchor w
-pack .configure.frame1.eat.lbl -side left  -anchor w
 pack .configure.frame1.eat.chk -side left  -anchor w
-pack .configure.frame1.all     -side top   -anchor w
-pack .configure.frame1.all.lbl -side left  -anchor w
-pack .configure.frame1.all.chk -side left  -anchor w
+pack .configure.frame1.eat.lbl -side left  -anchor w
 pack .configure.frame1.atk     -side top   -anchor w
-pack .configure.frame1.atk.lbl -side left  -anchor w
 pack .configure.frame1.atk.chk -side left  -anchor w
+pack .configure.frame1.atk.lbl -side left  -anchor w
+pack .configure.frame1.all     -side top   -anchor w
+pack .configure.frame1.all.chk -side left  -anchor w
+pack .configure.frame1.all.lbl -side left  -anchor w
 pack .configure.button -side bottom -anchor s
 
 }
@@ -478,7 +493,7 @@ button .rule.flag.uk -image $flag_uk -command rule_uk
 button .rule.flag.fr -image $flag_fr -command rule_fr
 button .rule.flag.sp -image $flag_sp -command rule_sp
 text .rule.txt -relief sunken -bd 2 -yscrollcommand ".rule.scroll set" -setgrid 1 \
- -height 30 -width 100 -spacing2 5;
+ -height 37 -width 100 -spacing2 5;
 scrollbar .rule.scroll -command ".rule.txt yview"
 pack .rule.flag.uk -side left -padx 5 -pady 5
 pack .rule.flag.fr -side left -padx 5 -pady 5
@@ -516,9 +531,17 @@ comer ms de cuatro agujeros consecutivos. Solo se comen los cuatro ltimos agujer
 cinco agujeros o ms se pueden comer.
 
 El jugador tiene entonces que dar semillas al adversario cuando no le quedan ms a este. \
-Si no puede dar ms semillas, la partida se para.
+Si no se pueden dar ms semillas, la partida se para.
 
 El jugador que ha comido ms semillas ha ganado.
+
+VARIANTES :
+Existen muchas variantes en Africa. La mayora se pueden jugar configurando la regla con los\
+cuatro parmetros siguientes.
+- el nmero mximo E de agujeros que se pueden comer puede ser modificado (E=1 a 6).
+- no se come nada cuando la cantidad de agujeros que se pueden comer es superior al nmero mximo E.
+- se puede prohibir atacar todas las semillas adversas menos si no hay otra alternativa.
+- cuando se atacan todas las semillas adversas, no se come nada.
 }
 }
 
@@ -549,6 +572,14 @@ Le joueur est tenu de fournir des graines  l'adversaire lorsque celui-ci n'en po
 S'il ne peut pas fournir de graines, la partie s'arrte.
 
 Le joueur qui a "mang" le plus de graines a gagn.
+
+VARIANTES :
+Il existe de nombreuses variantes en Afrique. La plupart d'entre elles peuvent tre joues en\
+configurant la rgle avec les quatre paramtres suivants.
+- le nombre maximum E de trous pouvant tre mangs peut tre modifi (E=1  6).
+- on ne mange rien lorsque plus de E trous sont "mangeables".
+- vous pouvez interdire d'attaquer toutes les graines adverses, sauf si c'est le seul coup jouable.
+- lorsque toutes les graines adverses sont attaques, rien n'est mang.
 }
 }
 
@@ -580,6 +611,14 @@ Players have to play such that the opponent always has at least one seed. \
 In case it is impossible, the game stops.
 
 The winner is the player who has eaten the most seeds.
+
+VARIANTS:
+It exists many variants in Africa. Most of them can be played\
+by configuring the rule with the four following parameters.
+- the maximum number E of holes that can be eaten can be modified (E=1 to 6).
+- instead of eating the last E holes when attacking more, you eat nothing.
+- you can forbid any move attacking all opponent seeds excepted if this is the only possible move.
+- in case all opponent seeds are attacked, nothing is eaten.
 }
 }
 
@@ -642,19 +681,21 @@ set BIN [file dirname [info script]]
 set HOME $env(HOME)
 set PATH $HOME
 set level 0
-array set depth0 [list 2players 0 0 1 1 7 2 9 3 10]
+array set depth0 [list H 0 0 1 1 7 2 9 3 10]
 set start PLAYER
 set nbeat 4
-set noeat ""
-set noall ""
-set noatk ""
+set noeat " "
+set noall " "
+set noatk " "
 set label END
 for {set i 0} {$i<12} {incr i} {set idtrou($i) 0}
+set mvtcircle 0
 set iturn 0
 set indication 0
 array set Tmin [list 0 0   1 1 2 3  3 15]
 array set Tmax [list 0 999 1 2 2 20 3 100]
 
+array set SEED [list uk "seed(s)"        fr "graine(s)"          sp "semilla(s)"]
 array set PLAY [list uk "Play"           fr "Jeu"                sp "Jugar"]
 array set NEW  [list uk "New game"       fr "Nouvelle partie"    sp "Nueva partida"]
 array set OPEN [list uk "Open"           fr "Ouvrir"             sp "Abrir"]
@@ -679,6 +720,8 @@ array set FR   [list uk "Franais"       fr "Franais"           sp "Franais"]
 array set SP   [list uk "Castellano"     fr "Castellano"         sp "Castellano"]
 array set WIN  [list uk "You lose"       fr "Je t'ai bien gagn" sp "He ganado"]
 array set LOSE [list uk "You win"        fr "Tu m'as bien gagn" sp "Me has ganado"]
+array set NWIN [list uk "North wins"     fr "Nord a bien gagn"  sp "Norte ha ganado"]
+array set SWIN [list uk "South wins"     fr "Sud a bien gagn"   sp "Sur ha ganado"]
 array set DRAW [list uk "It's a draw"    fr "C'est mme score"   sp "Igualdad"]
 array set CSCO [list uk "Computer score" fr "Score ordinateur"   sp "Score del ordenador"]
 array set PSCO [list uk "Player score"   fr "Score joueur"       sp "Score del jugador"]
@@ -690,27 +733,27 @@ array set YES  [list uk "Yes"            fr "Oui"                sp "Si"]
 array set NO   [list uk "No"             fr "Non"                sp "No"]
 array set OK   [list uk "OK"             fr "OK"                 sp "VALE"]
 array set DEFA [list uk "DEFAULT" fr "DEFAUT" sp "DEFECTO"]
-array set MAXI [list uk "Maximum number of holes that can be eaten"\
-                     fr "Nombre maximum de trous  manger"\
-                     sp "Cantidad mxima de agujeros que comer"]
-array set EATL [list uk "Eat the last holes when trying to eat more than the maximum"\
-                     fr "Mange les derniers trous lorsqu'on dpasse le maximum"\
-                     sp "Come los ltimos agujeros cuando se pasa del mximo"]
-array set EATN [list uk "Eat nothing when trying to eat more than the maximum"\
-                     fr "Ne mange rien lorsqu'on dpasse le maximum"\
-                     sp "No come nada cuando se pasa del mximo"]
-array set EATA [list uk "Possible to eat all opponent seeds"\
-                     fr "Possibilit de manger toutes les graines adverses"\
+array set MAXI [list uk "Maximum number E of holes that can be eaten"\
+                     fr "Nombre maximum E de trous pouvant tre mangs"\
+                     sp "Cantidad mxima E de agujeros que comer"]
+array set EATL [list uk "Eat the last E holes when attacking more than E holes"\
+                     fr "Mange les E derniers trous lorsqu'on attaque plus de E trous"\
+                     sp "Se comen los E ltimos agujeros cuando se pasa del mximo E"]
+array set EATN [list uk "Eat nothing when attacking more than E holes"\
+                     fr "Ne mange rien lorsqu'on attaque plus de E trous"\
+                     sp "No se come nada cuando se pasa del mximo E"]
+array set EATA [list uk "Can eat all opponent seeds"\
+                     fr "Peut manger toutes les graines adverses"\
                      sp "Se puede comer todos los agujeros del adversario"]
 array set NOAL [list uk "Eat nothing when trying to eat all opponent seeds"\
                      fr "Ne mange rien lorsqu'on attaque toutes les graines adverses"\
-                     sp "No come nada cuando se intenta comer todas las semillas adversas"]
+                     sp "No se come nada cuando se intenta comer todas las semillas adversas"]
 array set ATKA [list uk "Allow to play a move which attacks all opponent seeds"\
-                     fr "Possibilit d'attaquer toutes les graines adverses"\
+                     fr "Peut jouer un coup qui attaque toutes les graines adverses"\
                      sp "Se puede atacar todos los agujeros del adversario"]
-array set NOAK [list uk "Forbidden to play a move which attacks all opponent seeds"\
-                     fr "Interdiction d'attaquer toutes les graines adverses"\
-                     sp "No se puede atacar todas las semillas adversas"]
+array set NOAK [list uk "Forbidden to attack all opponent seeds excepted if this is the only possible move"\
+                     fr "Interdiction d'attaquer toutes les graines adverses sauf si c'est le seul coup jouable"\
+                     sp "No se puede atacar todas las semillas adversas excepto si es la sola jugada posible"]
 array set IFIL [list uk "Select file to import" \
                      fr "Choisir le fichier  importer" \
                      sp "Elegir el fichero para importar"]
@@ -749,12 +792,12 @@ menu $m -tearoff 0
 .menu add cascade -label $PARA($LANG) -menu $m -underline 0
 $m add cascade -label $LEVE($LANG) -menu $m.level
 menu $m.level -tearoff 0
-$m.level add radio -label "$TWOP($LANG)"   -variable level -value "2players"
+$m.level add radio -label "$TWOP($LANG)"   -variable level -value "H" -command {changeLang}
 $m.level add radio -label "$OPPO($LANG) 0" -variable level -value 0 \
-                                           -command "set depth $depth0(0)"
-$m.level add radio -label "$OPPO($LANG) 1" -variable level -value 1
-$m.level add radio -label "$OPPO($LANG) 2" -variable level -value 2
-$m.level add radio -label "$OPPO($LANG) 3" -variable level -value 3
+                                           -command "set depth $depth0(0); changeLang"
+$m.level add radio -label "$OPPO($LANG) 1" -variable level -value 1 -command {changeLang}
+$m.level add radio -label "$OPPO($LANG) 2" -variable level -value 2 -command {changeLang}
+$m.level add radio -label "$OPPO($LANG) 3" -variable level -value 3 -command {changeLang}
 $m add cascade -label $STAR($LANG) -menu $m.start
 menu $m.start -tearoff 0
 $m.start add radio -label $BOTT($LANG) -variable start -value "PLAYER"
@@ -781,7 +824,8 @@ set fond [image create photo -file [file join $BIN Awale.gif]]
 set largeur [image width $fond]
 set hauteur [image height $fond]
 for {set i  0} {$i<10} {incr i} {set img($i) [image create photo -file [file join $BIN Trou0$i.gif]]}
-for {set i 10} {$i<49} {incr i} {set img($i) [image create photo -file [file join $BIN Trou09.gif]]}
+for {set i 10} {$i<16} {incr i} {set img($i) [image create photo -file [file join $BIN Trou$i.gif]]}
+for {set i 16} {$i<49} {incr i} {set img($i) [image create photo -file [file join $BIN Trou15.gif]]}
 
 canvas .cnv -width $largeur -height $hauteur -cursor top_left_arrow
 bind .cnv <ButtonPress-1> "jouer %x %y $largeur $hauteur"
